==> gpick_0.2.3.orig.tar.gz: gpick-0.2.3/source/Vector2.h <==
/*
 * Copyright (c) 2009-2010, Albertas Vyšniauskas
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
 *
 *     * Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
 *     * Neither the name of the software author nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
 * IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef VECTOR2_H_
#define VECTOR2_H_

namespace math{

/** \class Vec2
 * \brief Two dimensional vector
 */
template<typename T>
class Vec2{
public:
	Vec2(){
		x = y = 0;
	};

	Vec2(const T &x_, const T &y_){
		x = x_;
		y = y_;
	};

	Vec2(T &x_, T &y_){
		x = x_;
		y = y_;
	};

	Vec2& operator= (const Vec2& v){
    	x = v.x;
    	y = v.y;
    	return *this;
	};

	Vec2 operator* (const Vec2& v){
    	Vec2 r;
    	r.x = x * v.x;
    	r.y = y * v.y;
    	return r;
	};

	Vec2 operator* (const double& v){
    	Vec2 r;
    	r.x = x * v;
    	r.y = y * v;
    	return r;
	};

	Vec2 operator+ (const Vec2& v){
    	Vec2 r;
    	r.x = x + v.x;
    	r.y = y + v.y;
    	return r;
	};

	T x;
	T y;
};

}

#endif /* VECTOR2_H_ */

==> gpick_0.2.5.orig.tar.gz: gpick_0.2.5/source/Vector2.h <==
/*
 * Copyright (c) 2009-2012, Albertas Vyšniauskas
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
 *
 *     * Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
 *     * Neither the name of the software author nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
 * IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef VECTOR2_H_
#define VECTOR2_H_

#include <math.h>

namespace math{

/** \class Vec2
 * \brief Two dimensional vector
 */
template<typename T>
class Vec2{
public:
	Vec2(){
		x = y = 0;
	};

	Vec2(const T &x_, const T &y_){
		x = x_;
		y = y_;
	};

	Vec2(T &x_, T &y_){
		x = x_;
		y = y_;
	};

	Vec2& operator= (const Vec2& v){
    	x = v.x;
    	y = v.y;
    	return *this;
	};

	Vec2 operator* (const Vec2& v){
    	Vec2 r;
    	r.x = x * v.x;
    	r.y = y * v.y;
    	return r;
	};

	Vec2 operator* (const double& v){
    	Vec2 r;
    	r.x = x * v;
    	r.y = y * v;
    	return r;
	};

	Vec2 operator+ (const Vec2& v){
    	Vec2 r;
    	r.x = x + v.x;
    	r.y = y + v.y;
    	return r;
	};

	friend bool operator!= (const Vec2& lhs, const Vec2& rhs){
		if (lhs.x != rhs.x) return false;
		if (lhs.y != rhs.y) return false;
		return true;
	};

	static T distance(const Vec2&a, const Vec2& b){
    	return sqrt((a.x - b.x) * (a.x - b.x) + (a.y - b.y) * (a.y - b.y));
	};

	T x;
	T y;
};

}

#endif /* VECTOR2_H_ */
